pub struct PT_FD32(pub i32);Expand description
File descriptor (32-bit)
Tuple Fields
0: i32Trait Implementations
Sourceimpl FromBytes<'_> for Fd32
impl FromBytes<'_> for Fd32
Sourcefn from_bytes(buf: &mut &[u8]) -> Result<Fd32, FromBytesError>
fn from_bytes(buf: &mut &[u8]) -> Result<Fd32, FromBytesError>
Read the binary representation of a field and return the parsed representation Read more
Sourcefn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
fn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
Read the binary representation of a field from a buffer that may or may not exist Read more
Sourceimpl Ord for Fd32
impl Ord for Fd32
Sourceimpl PartialOrd for Fd32
impl PartialOrd for Fd32
Sourceimpl ToBytes for Fd32
impl ToBytes for Fd32
Sourcefn binary_size(&self) -> usize
fn binary_size(&self) -> usize
Return the number of bytes needed to store the field
Sourcefn write<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Write the binary representation to
writerSourcefn default_repr() -> impl ToBytes
fn default_repr() -> impl ToBytes
Return the default representation for the field type Read more
impl Copy for Fd32
impl Eq for Fd32
impl StructuralPartialEq for Fd32