pub struct PT_PID32(pub i32);Expand description
Process or thread id (32-bit)
Tuple Fields
0: i32Trait Implementations
Sourceimpl FromBytes<'_> for Pid32
impl FromBytes<'_> for Pid32
Sourcefn from_bytes(buf: &mut &[u8]) -> Result<Pid32, FromBytesError>
fn from_bytes(buf: &mut &[u8]) -> Result<Pid32, FromBytesError>
Read the binary representation of a field and return the parsed representation Read more
Sourcefn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
fn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
Read the binary representation of a field from a buffer that may or may not exist Read more
Sourceimpl Ord for Pid32
impl Ord for Pid32
Sourceimpl PartialOrd for Pid32
impl PartialOrd for Pid32
Sourceimpl ToBytes for Pid32
impl ToBytes for Pid32
Sourcefn binary_size(&self) -> usize
fn binary_size(&self) -> usize
Return the number of bytes needed to store the field
Sourcefn write<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Write the binary representation to
writerSourcefn default_repr() -> impl ToBytes
fn default_repr() -> impl ToBytes
Return the default representation for the field type Read more
impl Copy for Pid32
impl Eq for Pid32
impl StructuralPartialEq for Pid32